CaseConversionsOnStringExt extension

on

Properties

isLowerCase → bool

Available on String, provided by the CaseConversionsOnStringExt extension

Returns true if the string is identical to its lowercase form.
no setter
isUpperCase → bool

Available on String, provided by the CaseConversionsOnStringExt extension

Returns true if the string is identical to its uppercase form.
no setter

Methods

capitalize() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Capitalizes the first letter of the string.
toCamelCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to camelCase. Example: 'Hello World' -> 'helloWorld'
toCapitalizedKebabCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to Capitalized-Kebab-Case. Example: 'helloWorld' -> 'Hello-World'
toDotCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to dot.case.
toKebabCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to kebab-case.
toLowerDotCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to lower.dot.case (alias for toDotCase). Example: 'HelloWorld' -> 'hello.world'
toLowerKebabCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to lower-kebab-case (alias for toKebabCase). Example: 'HelloWorld' -> 'hello-world'
toLowerSnakeCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to lower_snake_case (alias for toSnakeCase). Example: 'HelloWorld' -> 'hello_world'
toPascalCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to PascalCase. Example: 'hello world' -> 'HelloWorld'
toPathCase([String separator = '/']) → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to path/case. Example: 'helloWorld' -> 'hello/world'
toSnakeCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to snake_case.
toUpperDotCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to UPPER.DOT.CASE. Example: 'HelloWorld' -> 'HELLO.WORLD'
toUpperKebabCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to UPPER-KEBAB-CASE. Example: 'helloWorld' -> 'HELLO-WORLD'
toUpperSnakeCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the string to UPPER_SNAKE_CASE. Example: 'helloWorld' -> 'HELLO_WORLD'
withCapitalizedWords() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Capitalizes each word in the string, assuming words are separated by spaces, hyphens, or underscores.
withFirstLetterAsLowerCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the first letter of the string to lowercase.
withFirstLetterAsUpperCase() → String

Available on String, provided by the CaseConversionsOnStringExt extension

Converts the first letter of the string to uppercase.