isLowerCase property

bool get isLowerCase

Returns true if the string is identical to its lowercase form.

Note that strings without any cased letters (empty, digit-only, punctuation-only, etc.) trivially equal their lowercase form and therefore also return true.

Implementation

bool get isLowerCase => this == toLowerCase();