isUpperCase property

bool get isUpperCase

Returns true if the string is identical to its uppercase form.

Note that strings without any cased letters (empty, digit-only, punctuation-only, etc.) trivially equal their uppercase form and therefore also return true.

Implementation

bool get isUpperCase => this == toUpperCase();