EquatableMixin mixin

A mixin that helps implement equality without needing to explicitly override operator == and hashCode.

Like with extending Equatable, the EquatableMixin overrides the operator == as well as the hashCode based on the provided props.

  1. @Deprecated('use Equatable as a mixin instead')
  2. @immutable

Properties

hashCode → int
The hash code for this object.
no setteroverride
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override