RecordUse constructor
const
RecordUse()
Creates a RecordUse instance.
This annotation can be placed on statically resolved members or classes whose usages in reachable code should be recorded.
Implementation
const RecordUse();